/*
 * Copyright (C) 2023  Aravinth Manivannan <realaravinth@batsense.net>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 */
//! Comments associated to an issue or a pull/merge request within the repository of a forge
//! (Gitea, GitLab, etc.)
use serde::{Deserialize, Serialize};

use crate::Reaction;

/// Comments associated to an issue or a pull/merge request within the repository of a forge
/// (Gitea, GitLab, etc.)
#[derive(Clone, Debug, Default, Serialize, Deserialize, Eq, PartialEq)]
pub struct Comment {
    /// Unique identifier of the issue or pull/merge request containing the comment
    pub issue_index: usize,

    /// Unique identifier of the comment
    pub index: String,

    /// Unique identifier of the user who authored the comment
    pub poster_id: String,

    // TODO: add validation for format "date-time"
    /// Creating time
    pub created: String,

    // TODO: add validation for format "date-time"
    /// Last update time
    pub updated: String,

    /// Multiline content of the comment
    pub content: String,

    /// Multiline content of the comment
    pub reactions: Option<Vec<Reaction>>,
}
