/*
 * Copyright (C) 2023  Aravinth Manivannan <realaravinth@batsense.net>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 */
//! Meta information and reference to an opaque content such as an image. The unique identifier is the SHA-256 of the content of the object.
use serde::{Deserialize, Serialize};

/// Meta information and reference to an opaque content such as an image. The unique identifier is the SHA-256 of the content of the object.
#[derive(Clone, Debug, Serialize, Deserialize, Default, Eq, PartialEq)]
pub struct Object {
    /// Unique identifier
    pub index: String,

    /// Human readable file name.
    pub name: String,

    /// Mime type of the object.
    pub mime: String,

    /// Description
    pub description: String,
}
